package edu.lawrence.temperature

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalSoftwareKeyboardController
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import edu.lawrence.temperature.ui.theme.TemperatureTheme

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
        setContent {
            TemperatureTheme {
                Scaffold(modifier = Modifier.fillMaxSize()) { innerPadding ->
                    TempCalculator(Modifier.padding(innerPadding))
                }
            }
        }
    }
}

@Composable
fun TempCalculator(modifier: Modifier = Modifier) {
    val fahrenheitTemp = remember { mutableStateOf("68")}
    val celsiusTemp = remember { mutableStateOf("20") }
    val orange = Color(0xFFFFA500)
    val keyboardController = LocalSoftwareKeyboardController.current
    Column(verticalArrangement = Arrangement.Center, horizontalAlignment = Alignment.CenterHorizontally, modifier = modifier.fillMaxSize()) {
        TextField(
            value = fahrenheitTemp.value,
            onValueChange = { newValue : String ->
                fahrenheitTemp.value = newValue
                val t = newValue.toDoubleOrNull()
                if(t == null)
                    celsiusTemp.value = "unknown"
                else {
                    val c = (t!! - 32.0)*5.0/9.0
                    celsiusTemp.value = "%.2f".format(c)
                }
            }
        )
        Column(horizontalAlignment = Alignment.CenterHorizontally,
            modifier = Modifier.clickable { keyboardController?.hide() }) {
            Text("degrees Fahrenheit", fontSize = 24.sp, color = orange,modifier=Modifier.padding(top=10.dp))
            Text("is", fontSize = 24.sp, color = orange,modifier=Modifier.padding(bottom=10.dp))
            Text(celsiusTemp.value)
            Text("degrees Celsius", fontSize = 24.sp, color = orange,modifier=Modifier.padding(top=10.dp))
        }
    }

}

@Preview(showBackground = true)
@Composable
fun GreetingPreview() {
    TemperatureTheme {
        TempCalculator()
    }
}